@@ -20,16 +20,6 @@ if sys.version_info >= (3, 8):
 else:
     import importlib_metadata
 
-HAS_RESULTLOG = False
-
-try:
-    from _pytest.resultlog import ResultLog
-
-    HAS_RESULTLOG = True
-except ImportError:
-    # We have a pytest >= 6.1
-    pass
-
 try:
     from xdist.newhooks import pytest_handlecrashitem
 
@@ -39,11 +29,6 @@ except ImportError:
     HAS_PYTEST_HANDLECRASHITEM = False
 
 
-PYTEST_GTE_54 = parse_version(pytest.__version__) >= parse_version("5.4")
-PYTEST_GTE_62 = parse_version(pytest.__version__) >= parse_version("6.2.0")
-PYTEST_GTE_63 = parse_version(pytest.__version__) >= parse_version("6.3.0.dev")
-
-
 def works_with_current_xdist():
     """Return compatibility with installed pytest-xdist version.
 
@@ -104,35 +89,11 @@ def pytest_addoption(parser):
         "regex provided. Pass this flag multiple times to accumulate a list "
         "of regexes to match",
     )
-    arg_type = "string" if PYTEST_GTE_62 else None
+    arg_type = "string"
     parser.addini("reruns", RERUNS_DESC, type=arg_type)
     parser.addini("reruns_delay", RERUNS_DELAY_DESC, type=arg_type)
 
 
-def _get_resultlog(config):
-    if not HAS_RESULTLOG:
-        return None
-    elif PYTEST_GTE_54:
-        # hack
-        from _pytest.resultlog import resultlog_key
-
-        return config._store.get(resultlog_key, default=None)
-    else:
-        return getattr(config, "_resultlog", None)
-
-
-def _set_resultlog(config, resultlog):
-    if not HAS_RESULTLOG:
-        pass
-    elif PYTEST_GTE_54:
-        # hack
-        from _pytest.resultlog import resultlog_key
-
-        config._store[resultlog_key] = resultlog
-    else:
-        config._resultlog = resultlog
-
-
 # making sure the options make sense
 # should run before / at the beginning of pytest_cmdline_main
 def check_options(config):
@@ -142,21 +103,9 @@ def check_options(config):
             if config.option.usepdb:  # a core option
                 raise pytest.UsageError("--reruns incompatible with --pdb")
 
-    resultlog = _get_resultlog(config)
-    if resultlog:
-        logfile = resultlog.logfile
-        config.pluginmanager.unregister(resultlog)
-        new_resultlog = RerunResultLog(config, logfile)
-        _set_resultlog(config, new_resultlog)
-        config.pluginmanager.register(new_resultlog)
-
 
 def _get_marker(item):
-    try:
-        return item.get_closest_marker("flaky")
-    except AttributeError:
-        # pytest < 3.6
-        return item.get_marker("flaky")
+    return item.get_closest_marker("flaky")
 
 
 def get_reruns_count(item):
@@ -279,10 +228,7 @@ def _remove_cached_results_from_failed_fixtures(item):
             if getattr(fixture_def, cached_result, None) is not None:
                 result, _, err = getattr(fixture_def, cached_result)
                 if err:  # Deleting cached results for only failed fixtures
-                    if PYTEST_GTE_54:
-                        setattr(fixture_def, cached_result, None)
-                    else:
-                        delattr(fixture_def, cached_result)
+                    setattr(fixture_def, cached_result, None)
 
 
 def _remove_failed_setup_state_from_session(item):
@@ -293,13 +239,7 @@ def _remove_failed_setup_state_from_session(item):
           and clean the stack itself
     """
     setup_state = item.session._setupstate
-    if PYTEST_GTE_63:
-        setup_state.stack = {}
-    else:
-        for node in setup_state.stack:
-            if hasattr(node, "_prepare_exc"):
-                del node._prepare_exc
-        setup_state.stack = []
+    setup_state.stack = {}
 
 
 def _get_rerun_filter_regex(item, regex_name):
@@ -316,6 +256,14 @@ def _get_rerun_filter_regex(item, regex_name):
 
 
 def _matches_any_rerun_error(rerun_errors, report):
+    return _try_match_reprcrash(rerun_errors, report)
+
+
+def _matches_any_rerun_except_error(rerun_except_errors, report):
+    return _try_match_reprcrash(rerun_except_errors, report)
+
+
+def _try_match_reprcrash(rerun_errors, report):
     for rerun_regex in rerun_errors:
         try:
             if re.search(rerun_regex, report.longrepr.reprcrash.message):
@@ -326,13 +274,6 @@ def _matches_any_rerun_error(rerun_errors, report):
     return False
 
 
-def _matches_any_rerun_except_error(rerun_except_errors, report):
-    for rerun_regex in rerun_except_errors:
-        if re.search(rerun_regex, report.longrepr.reprcrash.message):
-            return True
-    return False
-
-
 def _should_hard_fail_on_error(item, report):
     if report.outcome != "failed":
         return False
@@ -399,13 +340,11 @@ def pytest_configure(config):
 
 class XDistHooks:
     def pytest_configure_node(self, node):
-        """xdist hook"""
+        """Configure xdist hook for node sock_port."""
         node.workerinput["sock_port"] = node.config.failures_db.sock_port
 
     def pytest_handlecrashitem(self, crashitem, report, sched):
-        """
-        Return the crashitem from pending and collection.
-        """
+        """Return the crashitem from pending and collection."""
         db = sched.config.failures_db
         reruns = db.get_test_reruns(crashitem)
         if db.get_test_failures(crashitem) < reruns:
@@ -553,14 +492,9 @@ def pytest_runtest_teardown(item, nextitem):
         _remove_cached_results_from_failed_fixtures(item)
 
         if item in item.session._setupstate.stack:
-            if PYTEST_GTE_63:
-                for key in list(item.session._setupstate.stack.keys()):
-                    if key != item:
-                        del item.session._setupstate.stack[key]
-            else:
-                for node in list(item.session._setupstate.stack):
-                    if node != item:
-                        item.session._setupstate.stack.remove(node)
+            for key in list(item.session._setupstate.stack.keys()):
+                if key != item:
+                    del item.session._setupstate.stack[key]
 
 
 @pytest.hookimpl(hookwrapper=True)
@@ -593,10 +527,9 @@ def pytest_runtest_protocol(item, nextitem):
     check_options(item.session.config)
     delay = get_reruns_delay(item)
     parallel = not is_master(item.config)
-    item_location = (item.location[0] + "::" + item.location[2]).replace("\\", "/")
     db = item.session.config.failures_db
-    item.execution_count = db.get_test_failures(item_location)
-    db.set_test_reruns(item_location, reruns)
+    item.execution_count = db.get_test_failures(item.nodeid)
+    db.set_test_reruns(item.nodeid, reruns)
 
     if item.execution_count > reruns:
         return True
@@ -663,33 +596,3 @@ def show_rerun(terminalreporter, lines):
         for rep in rerun:
             pos = rep.nodeid
             lines.append(f"RERUN {pos}")
-
-
-if HAS_RESULTLOG:
-
-    class RerunResultLog(ResultLog):
-        def __init__(self, config, logfile):
-            ResultLog.__init__(self, config, logfile)
-
-        def pytest_runtest_logreport(self, report):
-            """Add support for rerun report."""
-            if report.when != "call" and report.passed:
-                return
-            res = self.config.hook.pytest_report_teststatus(report=report)
-            code = res[1]
-            if code == "x":
-                longrepr = str(report.longrepr)
-            elif code == "X":
-                longrepr = ""
-            elif report.passed:
-                longrepr = ""
-            elif report.failed:
-                longrepr = str(report.longrepr)
-            elif report.skipped:
-                longrepr = str(report.longrepr[2])
-            elif report.outcome == "rerun":
-                longrepr = str(report.longrepr)
-            else:
-                longrepr = str(report.longrepr)
-
-            self.log_outcome(report, code, longrepr)
